# OKLab Software Development Kit | Documentation

## Functions

### `get_response(prompt, max_tokens=4096, system_message=None)`

Returns the completion from the LLM model

**Parameters:**
- `prompt` (str): The prompt to send to the LLM model.
- `max_tokens` (int, optional): The maximum number of tokens to generate. Default is 4096.
- `system_message` (str, optional): An optional system message to include in the request. Can be used to tell the model some information about his role, information about the user etc.

**Returns:**
- `str`: The response generated by the LLM model.

**Usage:**
```python
get_response("Jake je to zit zavreny v bedne?")
```

### `convert_to_markdown(path, output_folder="output_page_markdowns")`

(beta)

Converts a PDF file to markdown format, page by page. Currently, this function only supports Azure deployments with Vision (Our OKBase Azure works).
Images are not yet supported, but soon will be

**Parameters:**
- `path` (str): The path to the PDF file to convert.
- `output_folder` (str, optional): The folder to save the markdown files. Default is "output_page_markdowns".

**Raises:**
- `Exception`: If a non-Azure LLM is used

**Usage:**
```python
convert_to_markdown("./path/to/pdf/file.pdf")
```


## Setup
### Installation
The library is available over pip
```
pip install oklabsdk
```

### Configuration
In order for this library to work, you need to have a correct `.env` file in your root (main) folder of your project.
The file will be provided to the OKLab team. In this file, secret configuration resides. Therefore it should always be kept only locally on your device, never uploaded for example to GitHub. 
```
# Switch between OpenAI API (Borůvka's Llama) and Azure
USE_AZURE = 1

# LLAMA 
OPENAI_API_KEY = 
OPENAI_BASE_URL =   
OPENAI_MODEL_NAME =

# MS Azure
AZURE_OPENAI_API_KEY = 
AZURE_OPENAI_ENDPOINT = 
OPENAI_API_VERSION = 
AZURE_DEPLOYMENT_NAME = 
```
This configuration (but filled out) can stay the same in all your projects. You can switch between Borůvka and Azure by changing the first variable.

### Import
The last thing you need to do is import the functions you need.
```python
from oklabsdk import get_response, convert_to_markdown

print(get_response("Mels me vubec rad?"))
```

